@@ -56,10 +56,10 @@ class Decoder_FEN():
                 count_king_black+=1
             if square != 'empty':
                 figures +=1
-        print(figures)
-        print(len(figures))
-        print(count_king_black)
-        print(count_king_white)
+        print(f'figures:{figures}')
+        print(f'len figures:{len(figures)}')
+        print(f'kb:{count_king_black}')
+        print(f'kw:{count_king_white}')
         if ((count_king_black != 1) or (count_king_white != 1) or ((figures) > 32)):
             raise InvalidChessboardLayout()
 
